pub struct SinglePassConfig {
pub theta_ns: f64,
pub pass_threshold: f64,
pub fail_threshold: f64,
pub bootstrap_iterations: usize,
pub timer_resolution_ns: f64,
pub seed: u64,
pub max_variance_ratio: f64,
}Expand description
Configuration for single-pass analysis.
Fields
theta_ns: f64Minimum effect threshold in nanoseconds.
pass_threshold: f64False positive rate threshold (default 0.05).
fail_threshold: f64False negative rate threshold (default 0.95).
bootstrap_iterations: usizeNumber of bootstrap iterations for covariance estimation (default 2000).
timer_resolution_ns: f64Timer resolution in nanoseconds (default 1.0 for pre-collected data). Set this to the actual timer resolution if known (e.g., 41.7 for Apple Silicon cntvct_el0).
seed: u64Random seed for reproducibility.
max_variance_ratio: f64Maximum variance ratio for quality gate (default 0.95). If posterior variance > this fraction of prior variance, data is not informative.
Implementations
Sourceimpl SinglePassConfig
impl SinglePassConfig
Sourcepub fn for_attacker(model: AttackerModel) -> Self
pub fn for_attacker(model: AttackerModel) -> Self
Create config from an attacker model.
Sourcepub fn with_timer_resolution(self, resolution_ns: f64) -> Self
pub fn with_timer_resolution(self, resolution_ns: f64) -> Self
Set the timer resolution (useful when analyzing data from known timer sources).